class!() { /* proc-macro */ }Expand description
The class! macro for defining CSS classes with style properties.
Each class definition creates a Css function that can be used
in html! via the class: attribute. Styles are automatically injected
into the DOM on first use.
Parameterized classes keep the normal function-call syntax. Wrap a
parameter reference in {} to make it part of the generated class name
by value; parameters referenced without braces keep the default
type-based class name.